[PATCH/RFC 10/23] m5mols: Comments and data structures cleanup

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Update data structures documentation, fix typos and use more descriptive
names for some structure members.

Signed-off-by: Sylwester Nawrocki <s.nawrocki@xxxxxxxxxxx>
Signed-off-by: Kyungmin Park <kyungmin.park@xxxxxxxxxxx>
---
 drivers/media/video/m5mols/m5mols.h          |   12 ++++++------
 drivers/media/video/m5mols/m5mols_controls.c |    8 ++++----
 2 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/media/video/m5mols/m5mols_controls.c b/drivers/media/video/m5mols/m5mols_controls.c
index d135d20..0730e50 100644
--- a/drivers/media/video/m5mols/m5mols_controls.c
+++ b/drivers/media/video/m5mols/m5mols_controls.c
@@ -190,11 +190,11 @@ static int m5mols_lock_ae(struct m5mols_info *info, bool lock)
 {
 	int ret = 0;
 
-	if (info->lock_ae != lock)
+	if (info->ae_locked != lock)
 		ret = m5mols_write(&info->sd, AE_LOCK,
 				lock ? REG_AE_LOCK : REG_AE_UNLOCK);
 	if (!ret)
-		info->lock_ae = lock;
+		info->ae_locked = lock;
 
 	return ret;
 }
@@ -203,11 +203,11 @@ static int m5mols_lock_awb(struct m5mols_info *info, bool lock)
 {
 	int ret = 0;
 
-	if (info->lock_awb != lock)
+	if (info->awb_locked != lock)
 		ret = m5mols_write(&info->sd, AWB_LOCK,
 				lock ? REG_AWB_LOCK : REG_AWB_UNLOCK);
 	if (!ret)
-		info->lock_awb = lock;
+		info->awb_locked = lock;
 
 	return ret;
 }
diff --git a/drivers/media/video/m5mols/m5mols.h b/drivers/media/video/m5mols/m5mols.h
index 4b021e1..35a3949 100644
--- a/drivers/media/video/m5mols/m5mols.h
+++ b/drivers/media/video/m5mols/m5mols.h
@@ -163,7 +163,7 @@ struct m5mols_version {
  * @ffmt: current fmt according to resolution type
  * @res_type: current resolution type
  * @irq_waitq: waitqueue for the capture
- * @flags: state variable for the interrupt handler
+ * @irq_done: set to 1 in the interrupt handler
  * @handle: control handler
  * @autoexposure: Auto Exposure control
  * @exposure: Exposure control
@@ -173,11 +173,11 @@ struct m5mols_version {
  * @zoom: Zoom control
  * @ver: information of the version
  * @cap: the capture mode attributes
- * @power: current sensor's power status
  * @isp_ready: 1 when the ISP controller has completed booting
+ * @power: current sensor's power status
  * @ctrl_sync: 1 when the control handler state is restored in H/W
  * @lock_ae: true means the Auto Exposure is locked
  * @lock_awb: true means the Aut WhiteBalance is locked
  * @resolution:	register value for current resolution
  * @mode: register value for current operation mode
  * @set_power: optional power callback to the board code
@@ -210,8 +210,8 @@ struct m5mols_info {
 	unsigned int power:1;
 	unsigned int ctrl_sync:1;
 
-	bool lock_ae;
-	bool lock_awb;
+	bool ae_locked;
+	bool awb_locked;
 	u8 resolution;
 	u8 mode;
 
@@ -173,11 +173,11 @@ struct m5mols_version {
  * @ctrl_sync: 1 when the control handler state is restored in H/W
- * @lock_ae: true means the Auto Exposure is locked
- * @lock_awb: true means the Aut WhiteBalance is locked
+ * @ae_locked: true when the Auto Exposure algorithm is locked
+ * @awb_locked: true when the Auto White Balance is locked
  * @resolution:	register value for current resolution
  * @mode: register value for current operation mode
-- 
1.7.9.2

--
To unsubscribe from this list: send the line "unsubscribe linux-media" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux Input]     [Video for Linux]     [Gstreamer Embedded]     [Mplayer Users]     [Linux USB Devel]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [Yosemite Backpacking]
  Powered by Linux